==> test-support-0.2.1-sources.jar: org/occurrent/testsupport/mongodb/FlushMongoDBExtension.java <==
/*
 * Copyright 2020 Johan Haleby
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.occurrent.testsupport.mongodb;

import com.mongodb.ConnectionString;
import com.mongodb.client.MongoClient;
import com.mongodb.client.MongoClients;
import org.junit.jupiter.api.extension.BeforeEachCallback;
import org.junit.jupiter.api.extension.ExtensionContext;

import static java.util.Objects.requireNonNull;

public class FlushMongoDBExtension implements BeforeEachCallback {

    private final ConnectionString connectionString;

    public FlushMongoDBExtension(ConnectionString connectionString) {
        this.connectionString = connectionString;
    }

    @Override
    public void beforeEach(ExtensionContext extensionContext) {
        String databaseName = requireNonNull(connectionString.getDatabase(), "Database cannot be null in MongoDB connection string");
        try (MongoClient mongoClient = MongoClients.create(connectionString)) {
            mongoClient.getDatabase(databaseName).drop();
        }
    }
}

==> test-support-0.7.0-sources.jar: org/occurrent/testsupport/mongodb/FlushMongoDBExtension.java <==
/*
 * Copyright 2020 Johan Haleby
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.occurrent.testsupport.mongodb;

import com.mongodb.ConnectionString;
import com.mongodb.client.MongoClient;
import com.mongodb.client.MongoClients;
import org.junit.jupiter.api.extension.BeforeEachCallback;
import org.junit.jupiter.api.extension.ExtensionContext;

import static java.util.Objects.requireNonNull;

public class FlushMongoDBExtension implements BeforeEachCallback {

    private final ConnectionString connectionString;

    public FlushMongoDBExtension(ConnectionString connectionString) {
        this.connectionString = connectionString;
    }

    @Override
    public void beforeEach(ExtensionContext extensionContext) {
        try {
            flushDb(0);
        } catch (InterruptedException e) {
            throw new RuntimeException(e);
        }
    }

    private void flushDb(int attempt) throws InterruptedException {
        String databaseName = requireNonNull(connectionString.getDatabase(), "Database cannot be null in MongoDB connection string");
        try (MongoClient mongoClient = MongoClients.create(connectionString)) {
            mongoClient.getDatabase(databaseName).drop();
        } catch (Throwable t) {
            System.out.println("Failed to flush database:" + t);
            Thread.sleep(100);
            if (attempt < 10) {
                flushDb(attempt + 1);
            }
        }
    }
}
